==> glfw-doc-3.3.9-1-aarch64.pkg.tar.xz: usr/share/doc/glfw/html/search/all_10.js <==
var searchData=
[
  ['macos_0',['macos',['../compat_guide.html#compat_osx',1,'OpenGL on macOS'],['../build_guide.html#build_link_osx',1,'With command-line on macOS'],['../build_guide.html#build_link_xcode',1,'With Xcode on macOS']]],
  ['macos_20menu_20bar_20from_20nib_20file_1',['macOS menu bar from nib file',['../news.html#macos_nib_33',1,'']]],
  ['macos_20specific_20cmake_20options_20and_20macros_2',['macOS specific CMake options and macros',['../news.html#macos_options_33',1,'']]],
  ['macos_20specific_20init_20hints_3',['macOS specific init hints',['../intro_guide.html#init_hints_osx',1,'']]],
  ['macos_20specific_20window_20hints_4',['macOS specific window hints',['../window_guide.html#window_hints_osx',1,'']]],
  ['macos_20via_20moltenvk_5',['Support for Vulkan on macOS via MoltenVK',['../news.html#moltenvk_33',1,'']]],
  ['macro_6',['Removal of GLFWCALL macro',['../moving_guide.html#moving_stdcall',1,'']]],
  ['macro_20for_20including_20extension_20header_7',['Macro for including extension header',['../news.html#news_31_glext',1,'']]],
  ['macros_8',['macros',['../internals_guide.html#internals_config',1,'Configuration macros'],['../build_guide.html#build_macros',1,'GLFW header option macros'],['../news.html#macos_options_33',1,'macOS specific CMake options and macros']]],
  ['main_20thread_20wake_20up_9',['Main thread wake-up',['../news.html#news_31_emptyevent',1,'']]],
  ['main_2edox_10',['main.dox',['../main_8dox.html',1,'']]],
  ['makefiles_20and_20pkg_20config_20on_20unix_11',['With makefiles and pkg-config on Unix',['../build_guide.html#build_link_pkgconfig',1,'']]],
  ['making_20the_20opengl_20context_20current_12',['Making the OpenGL context current',['../quick_guide.html#quick_context_current',1,'']]],
  ['management_13',['management',['../moving_guide.html#moving_context',1,'Explicit context management'],['../intro_guide.html#intro_version',1,'Version management']]],
  ['manually_14',['manually',['../compile_guide.html#compile_manual',1,'Compiling GLFW manually'],['../context_guide.html#context_glext_manual',1,'Loading extensions manually']]],
  ['mappings_15',['Gamepad mappings',['../input_guide.html#gamepad_mapping',1,'']]],
  ['masks_16',['Modifier key bit masks',['../news.html#news_30_keymods',1,'']]],
  ['maximization_17',['Window maximization',['../window_guide.html#window_maximize',1,'']]],
  ['maximization_20callback_18',['Window maximization callback',['../news.html#maximize_33',1,'']]],
  ['maxmimization_20support_19',['Window maxmimization support',['../news.html#news_32_maximize',1,'']]],
  ['may_20be_20rejected_20',['Gamma ramp size of 256 may be rejected',['../news.html#gamma_ramp_size_33',1,'']]],
  ['may_20lack_20alpha_20channel_20on_20older_20wayland_20systems_21',['Frambuffer may lack alpha channel on older Wayland systems',['../news.html#wayland_alpha_34',1,'']]],
  ['mbcs_20support_22',['Win32 MBCS support',['../moving_guide.html#moving_mbcs',1,'']]],
  ['menu_20bar_20from_20nib_20file_23',['macOS menu bar from nib file',['../news.html#macos_nib_33',1,'']]],
  ['mingw_24',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['mingw_20or_20visual_20c_20on_20windows_25',['With MinGW or Visual C++ on Windows',['../build_guide.html#build_link_win32',1,'']]],
  ['mir_20support_26',['mir support',['../news.html#news_31_mir',1,'(Experimental) Mir support'],['../news.html#mir_removed_33',1,'Mir support']]],
  ['mode_27',['Cursor mode',['../input_guide.html#cursor_mode',1,'']]],
  ['mode_20enumeration_28',['Video mode enumeration',['../moving_guide.html#moving_video_modes',1,'']]],
  ['mode_20switching_29',['Window mode switching',['../news.html#news_32_setwindowmonitor',1,'']]],
  ['modes_30',['Video modes',['../monitor_guide.html#monitor_modes',1,'']]],
  ['modifier_20key_20bit_20masks_31',['Modifier key bit masks',['../news.html#news_30_keymods',1,'']]],
  ['modifier_20key_20flags_32',['Modifier key flags',['../group__mods.html',1,'']]],
  ['modifiers_20callback_33',['modifiers callback',['../news.html#news_31_charmods',1,'Character with modifiers callback'],['../news.html#charmods_callback_33',1,'Character with modifiers callback']]],
  ['moltenvk_34',['Support for Vulkan on macOS via MoltenVK',['../news.html#moltenvk_33',1,'']]],
  ['monitor_35',['Window monitor',['../window_guide.html#window_monitor',1,'']]],
  ['monitor_20and_20joystick_20user_20pointers_36',['Monitor and joystick user pointers',['../news.html#device_userptr_33',1,'']]],
  ['monitor_20configuration_20changes_37',['Monitor configuration changes',['../monitor_guide.html#monitor_event',1,'']]],
  ['monitor_20guide_38',['Monitor guide',['../monitor_guide.html',1,'']]],
  ['monitor_20objects_39',['Monitor objects',['../monitor_guide.html#monitor_object',1,'']]],
  ['monitor_20properties_40',['Monitor properties',['../monitor_guide.html#monitor_properties',1,'']]],
  ['monitor_20reference_41',['Monitor reference',['../group__monitor.html',1,'']]],
  ['monitor_20related_20hints_42',['Monitor related hints',['../window_guide.html#window_hints_mtr',1,'']]],
  ['monitor_20rendering_43',['Simultaneous multi-monitor rendering',['../news.html#news_31_autoiconify',1,'']]],
  ['monitor_20selection_44',['Explicit monitor selection',['../moving_guide.html#moving_monitor',1,'']]],
  ['monitor_20support_45',['Multi-monitor support',['../news.html#news_30_multimon',1,'']]],
  ['monitor_20work_20area_46',['Query for the monitor work area',['../news.html#workarea_33',1,'']]],
  ['monitor_2edox_47',['monitor.dox',['../monitor_8dox.html',1,'']]],
  ['monitors_48',['Retrieving monitors',['../monitor_guide.html#monitor_monitors',1,'']]],
  ['more_20context_20creation_20extensions_49',['Support for more context creation extensions',['../news.html#glext_33',1,'']]],
  ['motion_50',['motion',['../input_guide.html#raw_mouse_motion',1,'Raw mouse motion'],['../news.html#raw_motion_33',1,'Support for raw mouse motion']]],
  ['mouse_20button_20input_51',['Mouse button input',['../input_guide.html#input_mouse_button',1,'']]],
  ['mouse_20buttons_52',['Mouse buttons',['../group__buttons.html',1,'']]],
  ['mouse_20cursor_20hover_20window_20attribute_53',['Mouse cursor hover window attribute',['../news.html#cursor_hover_33',1,'']]],
  ['mouse_20cursor_20images_54',['Custom mouse cursor images',['../news.html#news_31_cursor',1,'']]],
  ['mouse_20input_55',['Mouse input',['../input_guide.html#input_mouse',1,'']]],
  ['mouse_20motion_56',['mouse motion',['../input_guide.html#raw_mouse_motion',1,'Raw mouse motion'],['../news.html#raw_motion_33',1,'Support for raw mouse motion']]],
  ['moving_20from_20glfw_202_20to_203_57',['Moving from GLFW 2 to 3',['../moving_guide.html',1,'']]],
  ['moving_2edox_58',['moving.dox',['../moving_8dox.html',1,'']]],
  ['multi_20monitor_20rendering_59',['Simultaneous multi-monitor rendering',['../news.html#news_31_autoiconify',1,'']]],
  ['multi_20monitor_20support_60',['Multi-monitor support',['../news.html#news_30_multimon',1,'']]],
  ['multi_20window_20support_61',['Multi-window support',['../news.html#news_30_multiwnd',1,'']]]
];

==> glfw-doc-3.3.10-1-aarch64.pkg.tar.xz: usr/share/doc/glfw/html/search/all_10.js <==
var searchData=
[
  ['macos_0',['MacOS',['../compat_guide.html#compat_osx',1,'OpenGL on macOS'],['../build_guide.html#build_link_osx',1,'With command-line or makefile on macOS'],['../build_guide.html#build_link_xcode',1,'With Xcode on macOS']]],
  ['macos_20menu_20bar_20from_20nib_20file_1',['macOS menu bar from nib file',['../news.html#macos_nib_33',1,'']]],
  ['macos_20specific_20cmake_20options_20and_20macros_2',['macOS specific CMake options and macros',['../news.html#macos_options_33',1,'']]],
  ['macos_20specific_20init_20hints_3',['macOS specific init hints',['../intro_guide.html#init_hints_osx',1,'']]],
  ['macos_20specific_20window_20hints_4',['macOS specific window hints',['../window_guide.html#window_hints_osx',1,'']]],
  ['macos_20via_20moltenvk_5',['Support for Vulkan on macOS via MoltenVK',['../news.html#moltenvk_33',1,'']]],
  ['macro_6',['Removal of GLFWCALL macro',['../moving_guide.html#moving_stdcall',1,'']]],
  ['macro_20for_20including_20extension_20header_7',['Macro for including extension header',['../news.html#news_31_glext',1,'']]],
  ['macros_8',['Macros',['../internals_guide.html#internals_config',1,'Configuration macros'],['../build_guide.html#build_macros',1,'GLFW header option macros'],['../news.html#macos_options_33',1,'macOS specific CMake options and macros']]],
  ['main_20thread_20wake_20up_9',['Main thread wake-up',['../news.html#news_31_emptyevent',1,'']]],
  ['main_2edox_10',['main.dox',['../main_8dox.html',1,'']]],
  ['makefile_20on_20macos_11',['With command-line or makefile on macOS',['../build_guide.html#build_link_osx',1,'']]],
  ['making_20the_20opengl_20context_20current_12',['Making the OpenGL context current',['../quick_guide.html#quick_context_current',1,'']]],
  ['management_13',['Management',['../moving_guide.html#moving_context',1,'Explicit context management'],['../intro_guide.html#intro_version',1,'Version management']]],
  ['manually_14',['Manually',['../compile_guide.html#compile_manual',1,'Compiling GLFW manually'],['../context_guide.html#context_glext_manual',1,'Loading extensions manually']]],
  ['mappings_15',['Gamepad mappings',['../input_guide.html#gamepad_mapping',1,'']]],
  ['masks_16',['Modifier key bit masks',['../news.html#news_30_keymods',1,'']]],
  ['maximization_17',['Window maximization',['../window_guide.html#window_maximize',1,'']]],
  ['maximization_20callback_18',['Window maximization callback',['../news.html#maximize_33',1,'']]],
  ['maxmimization_20support_19',['Window maxmimization support',['../news.html#news_32_maximize',1,'']]],
  ['may_20be_20rejected_20',['Gamma ramp size of 256 may be rejected',['../news.html#gamma_ramp_size_33',1,'']]],
  ['may_20lack_20alpha_20channel_20on_20older_20wayland_20systems_21',['Framebuffer may lack alpha channel on older Wayland systems',['../news.html#wayland_alpha_33',1,'']]],
  ['mbcs_20support_22',['Win32 MBCS support',['../moving_guide.html#moving_mbcs',1,'']]],
  ['menu_20bar_20from_20nib_20file_23',['macOS menu bar from nib file',['../news.html#macos_nib_33',1,'']]],
  ['mingw_24',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['mingw_20w64_20and_20glfw_20binaries_25',['With MinGW-w64 and GLFW binaries',['../build_guide.html#build_link_mingw',1,'']]],
  ['mir_20support_26',['Mir support',['../news.html#news_31_mir',1,'(Experimental) Mir support'],['../news.html#mir_removed_33',1,'Mir support']]],
  ['mode_27',['Cursor mode',['../input_guide.html#cursor_mode',1,'']]],
  ['mode_20enumeration_28',['Video mode enumeration',['../moving_guide.html#moving_video_modes',1,'']]],
  ['mode_20switching_29',['Window mode switching',['../news.html#news_32_setwindowmonitor',1,'']]],
  ['modes_30',['Video modes',['../monitor_guide.html#monitor_modes',1,'']]],
  ['modifier_20key_20bit_20masks_31',['Modifier key bit masks',['../news.html#news_30_keymods',1,'']]],
  ['modifier_20key_20flags_32',['Modifier key flags',['../group__mods.html',1,'']]],
  ['modifiers_20callback_33',['Modifiers callback',['../news.html#charmods_callback_33',1,'Character with modifiers callback'],['../news.html#news_31_charmods',1,'Character with modifiers callback']]],
  ['moltenvk_34',['Support for Vulkan on macOS via MoltenVK',['../news.html#moltenvk_33',1,'']]],
  ['monitor_35',['Window monitor',['../window_guide.html#window_monitor',1,'']]],
  ['monitor_20and_20joystick_20user_20pointers_36',['Monitor and joystick user pointers',['../news.html#device_userptr_33',1,'']]],
  ['monitor_20configuration_20changes_37',['Monitor configuration changes',['../monitor_guide.html#monitor_event',1,'']]],
  ['monitor_20guide_38',['Monitor guide',['../monitor_guide.html',1,'']]],
  ['monitor_20objects_39',['Monitor objects',['../monitor_guide.html#monitor_object',1,'']]],
  ['monitor_20properties_40',['Monitor properties',['../monitor_guide.html#monitor_properties',1,'']]],
  ['monitor_20reference_41',['Monitor reference',['../group__monitor.html',1,'']]],
  ['monitor_20related_20hints_42',['Monitor related hints',['../window_guide.html#window_hints_mtr',1,'']]],
  ['monitor_20rendering_43',['Simultaneous multi-monitor rendering',['../news.html#news_31_autoiconify',1,'']]],
  ['monitor_20selection_44',['Explicit monitor selection',['../moving_guide.html#moving_monitor',1,'']]],
  ['monitor_20support_45',['Multi-monitor support',['../news.html#news_30_multimon',1,'']]],
  ['monitor_20work_20area_46',['Query for the monitor work area',['../news.html#workarea_33',1,'']]],
  ['monitor_2edox_47',['monitor.dox',['../monitor_8dox.html',1,'']]],
  ['monitors_48',['Retrieving monitors',['../monitor_guide.html#monitor_monitors',1,'']]],
  ['more_20context_20creation_20extensions_49',['Support for more context creation extensions',['../news.html#glext_33',1,'']]],
  ['motion_50',['Motion',['../input_guide.html#raw_mouse_motion',1,'Raw mouse motion'],['../news.html#raw_motion_33',1,'Support for raw mouse motion']]],
  ['mouse_20button_20input_51',['Mouse button input',['../input_guide.html#input_mouse_button',1,'']]],
  ['mouse_20buttons_52',['Mouse buttons',['../group__buttons.html',1,'']]],
  ['mouse_20cursor_20hover_20window_20attribute_53',['Mouse cursor hover window attribute',['../news.html#cursor_hover_33',1,'']]],
  ['mouse_20cursor_20images_54',['Custom mouse cursor images',['../news.html#news_31_cursor',1,'']]],
  ['mouse_20input_55',['Mouse input',['../input_guide.html#input_mouse',1,'']]],
  ['mouse_20motion_56',['Mouse motion',['../input_guide.html#raw_mouse_motion',1,'Raw mouse motion'],['../news.html#raw_motion_33',1,'Support for raw mouse motion']]],
  ['moving_20from_20glfw_202_20to_203_57',['Moving from GLFW 2 to 3',['../moving_guide.html',1,'']]],
  ['moving_2edox_58',['moving.dox',['../moving_8dox.html',1,'']]],
  ['multi_20monitor_20rendering_59',['Simultaneous multi-monitor rendering',['../news.html#news_31_autoiconify',1,'']]],
  ['multi_20monitor_20support_60',['Multi-monitor support',['../news.html#news_30_multimon',1,'']]],
  ['multi_20window_20support_61',['Multi-window support',['../news.html#news_30_multiwnd',1,'']]]
];
